"use client";

import { useCallback, useEffect, useState } from "react";

import { AnimatePresence, motion } from "framer-motion";
import { ChevronLeft, ChevronRight } from "lucide-react";

import { cn } from "@/lib/utils";

import { ImageBaseUrl } from "@/configs/api";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale } from "next-intl";
import { CompanyLogo } from "./company-logo";

export function CompaniesSwiper() {

	// const { agents } = useAgent();
	const { texts } = useBasicInfo();


	const [currentPage, setCurrentPage] = useState(0);
	const [itemsPerPage, setItemsPerPage] = useState(2); // Default value for SSR
	const locale = useLocale();

	const isRTL = locale === "ar";

	const getItemsPerPage = useCallback(() => {
		if (typeof window !== "undefined") {
			if (window.innerWidth >= 1024) return 6;
			if (window.innerWidth >= 768) return 4;
		}
		return 2;
	}, []);

	const totalPages = Math.ceil(texts?.our_clients?.length / itemsPerPage);

	const nextPage = useCallback(() => {
		setCurrentPage((prev) => (prev + 1) % totalPages);
	}, [totalPages]);

	const prevPage = useCallback(() => {
		setCurrentPage((prev) => (prev - 1 + totalPages) % totalPages);
	}, [totalPages]);

	useEffect(() => {
		const handleResize = () => {
			setItemsPerPage(getItemsPerPage());
		};

		// Set items per page on initial render
		setItemsPerPage(getItemsPerPage());

		window.addEventListener("resize", handleResize);

		return () => {
			window.removeEventListener("resize", handleResize);
		};
	}, [getItemsPerPage]);

	const displayedData = texts?.our_clients?.slice(
		currentPage * itemsPerPage,
		(currentPage + 1) * itemsPerPage
	);

	return (
		<section className="relative overflow-hidden pb-8 pt-12">
			<div className="container mx-auto max-w-7xl px-4 md:px-6 lg:px-8">
				<div className="relative">
					<motion.div
						className="flex items-center justify-between rounded-full bg-white px-8 py-4 shadow-lg"
						initial={{ opacity: 0, y: 20 }}
						animate={{ opacity: 1, y: 0 }}
						transition={{ duration: 0.5 }}
					>
						<motion.button
							className="flex h-10 w-10 items-center justify-center rounded-full bg-white text-[#2895C8]"
							onClick={isRTL ? nextPage : prevPage}
							whileHover={{ scale: 1.1 }}
							whileTap={{ scale: 0.9 }}
						>
							<ChevronLeft
								className={cn("h-6 w-6", { "rotate-180": locale === "ar" })}
							/>
						</motion.button>
						<div className="mx-4 flex flex-grow justify-between">
							<AnimatePresence mode="wait">
								{displayedData?.map(({ client_name, image }: any, index: number) => (
									<motion.div
										key={client_name?.[locale]}
										className={cn(
											"w-1/2 px-4 md:w-1/4 lg:w-1/6",
											isRTL ? "ml-auto" : "mr-auto"
										)}
										initial={{ opacity: 0, x: isRTL ? -50 : 50 }}
										animate={{ opacity: 1, x: 0 }}
										exit={{ opacity: 0, x: isRTL ? 50 : -50 }}
										transition={{ duration: 0.3, delay: index * 0.1 }}
									>
										<CompanyLogo
											name={client_name?.[locale]}
											logo={ImageBaseUrl + image}
											index={index}
										/>
									</motion.div>
								))}
							</AnimatePresence>
						</div>
						<motion.button
							className="flex h-10 w-10 items-center justify-center rounded-full bg-white text-[#2895C8]"
							onClick={isRTL ? prevPage : nextPage}
							whileHover={{ scale: 1.1 }}
							whileTap={{ scale: 0.9 }}
						>
							<ChevronRight
								className={cn("h-6 w-6", { "rotate-180": locale === "ar" })}
							/>
						</motion.button>
					</motion.div>

					{/* Page Indicators */}
					<div className="mt-8 flex items-center justify-center gap-2">
						{Array.from({ length: totalPages })?.map((_, index) => (
							<motion.button
								key={index}
								className={cn(
									"h-3 w-3 rounded-full bg-white transition-all",
									currentPage === index ? "opacity-100" : "opacity-30"
								)}
								onClick={() => setCurrentPage(index)}
								whileHover={{ scale: 1.2 }}
								whileTap={{ scale: 0.8 }}
							/>
						))}
					</div>
				</div>
			</div>
		</section>
	);
}
